@@ -1,6 +1,8 @@
 import os
 import ain.common.constants as constants
 import docker
+import subprocess
+from subprocess import Popen
 
 class Docker():
 
@@ -10,6 +12,8 @@ class Docker():
       print("[+] pull image.")
       client = docker.from_env()
       client.images.pull(image)
+      noneRemoveCommands = 'docker rmi -f $(sudo docker images ainblockchain/ain-worker-staging | grep "<none>" | awk "{print $3}")'
+      Popen(noneRemoveCommands.split(" "), shell=False, stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
 
       if gpu:
         runtime = "nvidia"
